@@ -29,11 +29,10 @@ CONFIG_DIR = os.path.join(USER_DIR, 'etc')
 LOG_DIR = os.path.join(USER_DIR, 'logs')
 TMP_DIR = os.path.join(USER_DIR, 'tmp')
 GNUPG_DIR = os.path.expanduser('~/.gnupg')
-HDF5_DIR = os.path.join(USER_DIR, 'hdf5')
 COOKIEJAR = os.path.join(USER_DIR, '.cookiejar')
 DEFAULT_CONFIG = os.path.join(CONFIG_DIR, 'metrique')
 
-for path in [USER_DIR, CONFIG_DIR, LOG_DIR, TMP_DIR, HDF5_DIR]:
+for path in [USER_DIR, CONFIG_DIR, LOG_DIR, TMP_DIR]:
     if not os.path.exists(path):
         os.makedirs(path)
 
@@ -60,9 +59,8 @@ class Config(JSONConf):
         self.defaults = {
             'api_version': 'v2',
             'api_rel_path': 'api/v2',
-            'async': True,
             'auto_login': True,
-            'batch_size': 250,
+            'batch_size': 5000,
             'cookiejar': COOKIEJAR,
             'configdir': CONFIG_DIR,
             'cube_pkgs': ['cubes'],
@@ -71,19 +69,18 @@ class Config(JSONConf):
             'gnupg_dir': GNUPG_DIR,
             'gnupg_fingerprint': None,
             'host': '127.0.0.1',
-            'hdf5_dir': HDF5_DIR,
             'logdir': LOG_DIR,
             'logfile': 'metrique.log',
             'log2file': True,
             'logstdout': True,
-            'max_workers': multiprocessing.cpu_count() * 3,
+            'max_workers': multiprocessing.cpu_count(),
             'password': None,
             'port': 5420,
             'retries': 1,
             'sort': -1,
-            'sql_batch_size': 250,
+            'sql_batch_size': 1000,
             'ssl': False,
-            'ssl_verify': True,
+            'ssl_verify': False,
             'tmpdir': TMP_DIR,
             'username': os.getenv('USER'),
             'userdir': USER_DIR,
