@@ -48,6 +48,7 @@ import simplejson as json
 import urllib
 
 from metrique import query_api, user_api, cube_api
+from metrique import regtest as regression_test
 from metrique.config import Config
 from metrique.utils import json_encode, get_cube
 from metriqueu.utils import utcnow
@@ -121,6 +122,9 @@ class BaseCube(MutableSequence):
         else:
             return pd.DataFrame()
 
+    def flush(self):
+        self.objects = []
+
     @property
     def objects(self):
         return self._objects
@@ -138,11 +142,14 @@ class BaseCube(MutableSequence):
         if not isinstance(objects, (BaseCube, list, tuple)):
             _t = type(objects)
             raise TypeError("container value must be a list; got %s" % _t)
-        if not all([type(o) is dict for o in objects]):
-            raise TypeError("object values must be dict")
-        if not all([o.get('_oid') is not None for o in objects]):
-            raise ValueError("_oid must be defined for all objs")
-        self._objects = self._normalize(objects)
+        if objects:
+            if not all([type(o) is dict for o in objects]):
+                raise TypeError("object values must be dict")
+            if not all([o.get('_oid') is not None for o in objects]):
+                raise ValueError("_oid must be defined for all objs")
+            self._objects = self._normalize(objects)
+        else:
+            self._objects = objects
 
     @objects.deleter
     def objects(self):
@@ -165,8 +172,6 @@ class BaseCube(MutableSequence):
             o = self._obj_fields(o)
             # convert empty strings to None (null)
             o = self._obj_nones(o)
-            # type conversion; if it looks like a float... it is, etc
-            o = self._obj_types(o)
             # add object meta data the metriqued requires be set per object
             o = self._obj_end(o)
             o = self._obj_start(o, start)
@@ -189,30 +194,6 @@ class BaseCube(MutableSequence):
     def _obj_nones(self, obj):
         return dict([(k, None) if v == '' else (k, v) for k, v in obj.items()])
 
-    def _obj_types(self, obj, type_map=None):
-        '''
-        type_map should be a dict with key:field value:type mapping
-        if not provided, run basic "auto-type" assignment
-        '''
-        _type = None
-        for f, v in obj.items():
-            if type_map:
-                _type = type_map.get(f)
-            if _type:
-                # apply the f's type if specified
-                # don't try to catch exceptions here; errors
-                # here are problems in the type map which need to be fixed
-                obj[f] = _type(v)
-            else:
-                try:
-                    # attempt to convert to float, fall back
-                    # to original string value otherwise
-                    obj[f] = float(v)
-                except (TypeError, ValueError):
-                    # leave as is
-                    pass
-        return obj
-
     def _obj_end(self, obj, default=None):
         obj['_end'] = obj.get('_end', default)
         return obj
@@ -279,10 +260,6 @@ class BaseClient(BaseCube):
         # set name if passed in, but don't overwrite default if not
         self.name = name or self.name or utc_str
 
-        self.hdf5_path = os.path.join(self.config.hdf5_dir, self.name + '.hd5')
-
-        # a path to 'journal' file, hdf5 or a dataframe or list of dicts
-        # set objects if passed in, but don't overwrite default if not
         self.objects = BaseCube(name=self.name, objects=objects)
 
         self.config.logdir = os.path.expanduser(self.config.logdir)
@@ -319,41 +296,16 @@ class BaseClient(BaseCube):
             return self.load_csv(path, **kwargs)
         elif filetype in ['json']:
             return self.load_json(path, **kwargs)
-        elif filetype in ['hd5']:
-            return self.load_hdf5(path, **kwargs)
         else:
             raise TypeError("Invalid filetype: %s" % filetype)
 
     def load_csv(self, path, **kwargs):
-        # load the file into hdf5, according to filetype
+        # load the file according to filetype
         return pd.read_csv(path, **kwargs)
 
     def load_json(self, path, **kwargs):
         return pd.read_json(path, **kwargs)
 
-    def load_hdf5(self, path=None, **kwargs):
-        if not path:
-            path = os.path.expanduser('~/.metrique/hdf5')
-            path = os.path.join(path, self.name + '.hd5')
-        return pd.read_hdf(path, 'objects', **kwargs)
-
-    def save_hdf5(self, append=True):
-        store = None
-        try:
-            store = pd.HDFStore(self.hdf5_path, complevel=9)
-            if store and append:
-                assert isinstance(store['objects'], pd.DataFrame)
-                # append the self.df to what's in store and save
-                store.put('objects', pd.concat((store['objects'], self.df)))
-            else:
-                # WARNING: Overwrites data previous in the hdf5
-                store.put('objects', self.df)
-        finally:
-            if store:
-                store.flush()
-                store.close()
-        return True
-
 #################### misc #######################
     def debug_set(self, level=None, logstdout=None, logfile=None):
         '''
@@ -469,6 +421,11 @@ class HTTPClient(BaseClient):
     query_sample = sample = query_api.sample
     query_aggregate = aggregate = query_api.aggregate
 
+    regtest = regression_test.regtest
+    regtest_create = regression_test.regtest_create
+    regtest_remove = regression_test.regtest_remove
+    regtest_list = regression_test.regtest_list
+
     def __init__(self, cube=None, owner=None, **kwargs):
         super(HTTPClient, self).__init__(**kwargs)
         self.owner = owner or self.config.username
@@ -534,7 +491,8 @@ class HTTPClient(BaseClient):
 
     def extract(self, *args, **kwargs):
         self.get_objects(*args, **kwargs)  # default: stores into self.objects
-        return self.cube_save()  # default: saves from self.objects
+        self.cube_save()  # default: saves from self.objects
+        return
 
     def get_cmd(self, owner, cube, api_name=None):
         '''
@@ -616,8 +574,7 @@ class HTTPClient(BaseClient):
         try:
             _response.raise_for_status()
         except Exception as e:
-            m = getattr(e, 'message')
-            content = '%s\n%s\n%s' % (_url, m, _response.content)
+            content = '%s\n%s\n%s' % (_url, str(e), _response.content)
             self.logger.error(content)
             raise
         return _response
